@@ -49,6 +49,14 @@ def get_auth_items(username, password):
 
 AUTH_ITEMS = get_auth_items(FRD_USER, FRD_PW)
 
+XSLT_FILE = os.path.join(
+    os.path.dirname(__file__),
+    "fixtures",
+    "make_tei.xslt"
+)
+
+XSL_DOC = ET.parse(XSLT_FILE)
+
 TEI_DUMMY = os.path.join(
     os.path.dirname(__file__),
     "fixtures",
@@ -88,26 +96,23 @@ class FrdClient():
         self,
         out_dir=CUR_LOC,
         endpoint=FRD_API,
+        xsl_doc=XSL_DOC,
         auth_items={},
-        page_size=10,
         limit=10,
-        sleep=0.5
     ):
 
         """ initializes the class
 
+        :param out_dir: The directory to save processed Manifestations
+        :type out_dir: str
         :param endpoint: The API Endpoint
-        :type gnd_id: str
-        :param user: The API user name
-        :type user: str
-        :param pw: The user's password
-        :type pw: str
-        :param page_size: Default page size of api-return -> &page[limit]={self.limit}
-        :type pw: int
+        :type endpoint: str
+        :param xsl_doc: A `lxml.etree._ElementTree` object (i.e. a parsed XSL-Stylesheet)
+        :type xsl_doc: lxml.etree._ElementTree
+        :param auth_items: The result dict of a successfull drupal api login action
+        :type auth_items: dict
         :param limit: After how many next-loads the loop should stop
         :type pw: int
-        :param sleep: Time to pause crawling loop
-        :type pw: float
 
         :return: A FrdClient instance
         """
@@ -115,9 +120,7 @@ class FrdClient():
         self.endpoint = endpoint
         self.auth_items = auth_items
         self.cookie = self.auth_items['cookie']
-        self.page_size = page_size
         self.limit = limit
-        self.sleep = sleep
         self.werk_ep = f"{self.endpoint}node/werk"
         self.manifestation_ep = f"{self.endpoint}node/manifestation"
         self.nsmap = {
@@ -126,6 +129,7 @@ class FrdClient():
         }
         self.tei_dummy = self.tei_dummy()
         self.out_dir = out_dir
+        self.xsl_doc = xsl_doc
 
 
 class FrdWerk(FrdClient):
@@ -155,7 +159,7 @@ class FrdWerk(FrdClient):
 
     def get_manifestations(self):
         man_col = []
-        url = f"{self.manifestation_ep}?filter[field_werk.id]={self.werk_id}&fields[node--manifestation]=id,title"
+        url = f"{self.manifestation_ep}{self.filtered_url}&fields[node--manifestation]=id,title"
         next_page = True
         while next_page:
             print(url)
@@ -185,6 +189,7 @@ class FrdWerk(FrdClient):
     def __init__(
         self,
         werk_id=None,
+        filter_finished=True,
         **kwargs
     ):
         super().__init__(**kwargs)
@@ -192,6 +197,11 @@ class FrdWerk(FrdClient):
         self.ep = f"{self.werk_ep}/{self.werk_id}"
         self.werk = self.get_werk()
         self.werk_attrib = self.werk['data']['attributes']
+        self.filter_finished = filter_finished
+        if filter_finished:
+            self.filtered_url = f"?filter[field_werk.id]={self.werk_id}&filter[field_umschrift]=1"
+        else:
+            self.filtered_url = f"?filter[field_werk.id]={self.werk_id}"
         for x in self.werk_attrib.keys():
             value = self.werk_attrib[x]
             if isinstance(value, dict):
@@ -223,7 +233,7 @@ class FrdManifestation(FrdClient):
         :rtype: dict
         """
         r = requests.get(
-            f"{self.manifestation_endpoint}?include=field_werk",
+            f"{self.manifestation_endpoint}?include=field_werk,field_publication",
             cookies=self.cookie,
             allow_redirects=True
         )
@@ -232,20 +242,16 @@ class FrdManifestation(FrdClient):
         return result
 
     def get_manifestation_save_path(self):
-        werk_path = self.werk_folder
-        manifestation_path = self.md__path__alias
-        cur_werk_folder = werk_path.split('/')[:3]
-        cur_man_folder = manifestation_path.split('/')[2]
-        man_file_name = f"{manifestation_path.split('/')[-1]}.xml"
-        file_name = os.path.join(
-            self.save_dir, *cur_werk_folder, cur_man_folder, man_file_name
-        )
         folder = os.path.join(
-            self.save_dir, *cur_werk_folder, cur_man_folder
+            self.save_dir,
+            'werke',
+            self.werk_folder.split('/')[-1]
         )
+        file_name = f"{'__'.join(self.md__path__alias.split('/')[2:])}.xml"
         return {
-            "full_file_name": file_name,
-            "folder": folder
+            "full_file_name": os.path.join(folder, file_name),
+            "folder": folder,
+            "file_name": file_name
         }
 
     def get_pages(self):
@@ -309,7 +315,7 @@ class FrdManifestation(FrdClient):
         page_attributes = page_json['data']['attributes']
         page_id = page_json['data']['id']
         body = page_attributes['body']['processed']
-        wrapped_body = f'<div xml:id="page__{page_id}">{body}</div>'
+        wrapped_body = f'<div xmlns="http://www.tei-c.org/ns/1.0" xml:id="page__{page_id}">{body}</div>'
         cleaned_body = clean_markup(wrapped_body)
         faks = page_json['included'][0]
         page_nr = extract_page_nr(page_attributes['title'])
@@ -343,6 +349,8 @@ class FrdManifestation(FrdClient):
         ] = f"manifestation__{self.manifestation_id}"
         title = doc.xpath('//tei:title[@type="manifestation"]', namespaces=self.nsmap)[0]
         title.text = f"{self.md__title}"
+        p_title = doc.xpath('//tei:title[@type="publication"]', namespaces=self.nsmap)[0]
+        p_title.text = f"{self.publication['attributes']['title']}"
         w_title = doc.xpath('//tei:title[@type="work"]', namespaces=self.nsmap)[0]
         w_title.text = f"{self.werk['attributes']['title']}"
         body = doc.xpath('//tei:body', namespaces=self.nsmap)[0]
@@ -360,9 +368,11 @@ class FrdManifestation(FrdClient):
                 pp['faks__url'],
                 pp['faks__id']
             )
-            cur_div = div.xpath('//div', namespaces=self.nsmap)[0]
+            cur_div = div.xpath('//tei:div', namespaces=self.nsmap)[0]
             cur_div.insert(0, pb_el)
             body.append(div)
+        transform = ET.XSLT(self.xsl_doc)
+        tei = transform(doc)
         if save:
             try:
                 os.makedirs(self.manifestation_save_location_folder)
@@ -370,8 +380,8 @@ class FrdManifestation(FrdClient):
                 print(f"Overriding exsting file: {self.manifestation_save_location_folder}")
             file = self.manifestation_save_location_file
             with open(file, 'wb') as f:
-                f.write(ET.tostring(doc, encoding="utf-8"))
-        return doc
+                f.write(ET.tostring(tei, pretty_print=True, encoding="utf-8"))
+        return tei
 
     def __init__(
         self,
@@ -383,6 +393,7 @@ class FrdManifestation(FrdClient):
         self.manifestation_endpoint = f"{self.endpoint}node/manifestation/{manifestation_id}"
         self.manifestation = self.get_manifest()
         self.werk = self.manifestation['included'][0]
+        self.publication = self.manifestation['included'][1]
         self.werk_folder = self.werk['attributes']['path']['alias']
         # self.manifestation_folder = self.manifestation['attributes']['path']['alias']
         self.man_attrib = self.manifestation['data']['attributes']
